##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/settings/operation/SettingsExperimentalInspect)Retrieve Portainer experimental settings
Retrieve Portainer experimental settings. **Access policy** : authenticated
##### Authorizations:
_ApiKeyAuth_ _jwt_
### Responses
**200**
Success
**500**
Server error
get/settings/experimental
https://api-docs.portainer.io/api/settings/experimental
###  Response samples
  * 200


Content type
application/json
Copy
Expand all  Collapse all
`{
  *  "experimentalFeatures": { }

 }`
